package es.kauron.jstudy.model;

import javafx.beans.property.SimpleBooleanProperty;

import java.io.File;
import java.util.prefs.BackingStoreException;
import java.util.prefs.Preferences;

public class AppPrefs {
    private static final Preferences prefs = Preferences.userRoot();
    public static final BooleanPref repeatWrong = new BooleanPref(false, "repeatWrong");
    public static final BooleanPref showFeedback = new BooleanPref(true, "showFeedback");
    public static final BooleanPref repeatImmediately = new BooleanPref(false, "repeatImmediately");
    public static File lastDir;

    static {
        // Load data (booleanprefs are loaded automatically)
        String dirPath = prefs.get("lastDir", "");
        if (!dirPath.isEmpty()) lastDir = new File(dirPath);
    }

    private static void flushPrefs() {
        try {
            prefs.flush();
        } catch (BackingStoreException e) {
            e.printStackTrace();
        }
    }

    public static void save() {
        Preferences prefs = Preferences.userRoot();
        prefs.put("lastDir", lastDir == null ? "" : lastDir.getAbsolutePath());
        flushPrefs();
    }

    public static String printValues() {
        return String.format("repeatWrong=%b\nshowFeedback=%b", repeatWrong, showFeedback);
    }

    public static class BooleanPref extends SimpleBooleanProperty {
        private final String name;

        BooleanPref(boolean defValue, String name) {
            super(defValue);
            this.name = name;
            set(prefs.getBoolean(name, defValue));
            addListener((obj, o, n) -> this.save());
        }

        void save() {
            prefs.putBoolean(name, get());
            flushPrefs();
        }
    }
}
